@@ -2,7 +2,7 @@
 package JMX::Jmx4Perl::Agent;
 
 use JSON;
-use LWP::UserAgent;
+use URI::Escape;
 use HTTP::Request;
 use Carp;
 use strict;
@@ -131,7 +131,6 @@ sub request {
     my $url = $self->request_url($jmx_request);
     my $req = HTTP::Request->new(GET => $url);
     my $resp = $ua->request($req);
-    print Dumper($resp);
     my $ret = from_json($resp->content());
     if ($resp->is_error && !$ret->{status}) {
         my $error = "Error while fetching $url :\n" . $resp->status_line . "\n";
@@ -174,12 +173,17 @@ sub request_url {
 }
 
 # Escape '/' which are used as separators by using "/-/" as an escape sequence
-# Should be save within an URL
+# URI Encoding doesn't work for slashes, since some Appserver tend to mangle
+# them up with pathinfo-slashes too early in the request cycle.
+# E.g. Tomcat/Jboss croaks with a "HTTP/1.x 400 Invalid URI: noSlash" if one
+# uses an encoded slash somewhere in the path-info part.
 sub _escape {
     my $self = shift;
     my $input = shift;
-    $input =~ s|(/+)|"/" . ('-' x length($1)) . "/"|eg;
-    return $input;
+    $input =~ s|(/+)|"/" . ('-' x length($1)) . "/"|eg;    
+    return uri_escape_utf8($input,"^A-Za-z0-9\-_.!~*'()/");   # Added "/" to
+                                                              # default
+                                                              # set. See L<URI>
 }
 
 =back
